@@ -14,6 +14,8 @@ setClass("SEQopts",
     bootstrap.nboot = "integer",
     bootstrap = "logical",
     bootstrap.sample = "numeric",
+    bootstrap.CI_method = "character",
+    bootstrap.CI = "numeric",
     seed = "integer",
     followup.min = "numeric",
     followup.max = "numeric",
@@ -71,6 +73,8 @@ setClass("SEQopts",
     ncores = parallelly::availableCores(),
     bootstrap = FALSE,
     bootstrap.sample = 0.8,
+    bootstrap.CI_method = "se",
+    bootstrap.CI = 0.95,
     seed = 1636L,
     followup.min = -Inf,
     followup.max = Inf,
